package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.EmsFacsEvent;

/**
 * 能源设施事件Service接口
 *
 * @author ruoyi
 * @date 2024-08-22
 */
public interface IEmsFacsEventService {
    /**
     * 查询能源设施事件
     *
     * @param id 能源设施事件主键
     * @return 能源设施事件
     */
    EmsFacsEvent selectEmsFacsEventById(Long id);

    /**
     * 查询能源设施事件列表
     *
     * @param emsFacsEvent 能源设施事件
     * @return 能源设施事件集合
     */
    List<EmsFacsEvent> selectEmsFacsEventList(EmsFacsEvent emsFacsEvent);

    /**
     * 新增能源设施事件
     *
     * @param emsFacsEvent 能源设施事件
     * @return 结果
     */
    int insertEmsFacsEvent(EmsFacsEvent emsFacsEvent);

    /**
     * 批量新增能源设施事件
     *
     * @param emsFacsEvents 能源设施事件列表
     * @return 结果
     */
    int insertEmsFacsEventBatch(List<EmsFacsEvent> emsFacsEvents);

    /**
     * 修改能源设施事件
     *
     * @param emsFacsEvent 能源设施事件
     * @return 结果
     */
    int updateEmsFacsEvent(EmsFacsEvent emsFacsEvent);

    /**
     * 批量删除能源设施事件
     *
     * @param ids 需要删除的能源设施事件主键集合
     * @return 结果
     */
    int deleteEmsFacsEventByIds(Long[] ids);

    /**
     * 删除能源设施事件信息
     *
     * @param id 能源设施事件主键
     * @return 结果
     */
    int deleteEmsFacsEventById(Long id);

    /**
     * 删除能源设施事件信息
     *
     * @param facsCode 设施编码
     * @return 结果
     */
    int deleteEventByFacsCode(String facsCode);
}
