package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.EmsFacsEvent;

/**
 * 能源设施事件Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-22
 */
public interface EmsFacsEventMapper
{
    /**
     * 查询能源设施事件
     * 
     * @param id 能源设施事件主键
     * @return 能源设施事件
     */
     EmsFacsEvent selectEmsFacsEventById(Long id);

    /**
     * 查询能源设施事件列表
     * 
     * @param emsFacsEvent 能源设施事件
     * @return 能源设施事件集合
     */
     List<EmsFacsEvent> selectEmsFacsEventList(EmsFacsEvent emsFacsEvent);

    /**
     * 新增能源设施事件
     * 
     * @param emsFacsEvent 能源设施事件
     * @return 结果
     */
     int insertEmsFacsEvent(EmsFacsEvent emsFacsEvent);

    /**
     * 批量新增能源设施事件
     *
     * @param list 能源设施事件
     * @return 结果
     */
    int insertEmsFacsEventBatch(List<EmsFacsEvent> list);

    /**
     * 修改能源设施事件
     * 
     * @param emsFacsEvent 能源设施事件
     * @return 结果
     */
     int updateEmsFacsEvent(EmsFacsEvent emsFacsEvent);

    /**
     * 删除能源设施事件
     * 
     * @param id 能源设施事件主键
     * @return 结果
     */
     int deleteEmsFacsEventById(Long id);

    /**
     * 批量删除能源设施事件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteEmsFacsEventByIds(Long[] ids);

    /**
     * 根据设施code删除
     *
     * @param facsCode 设施编码
     * @return 结果
     */
    int deleteEmsFacsEventByFacsCode(String facsCode);
}
